using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using PhoenixDLL.Class;
using PhoenixDLL.GUI;
using PhoenixDLL.Class.Managers;
using PhoenixDLL.GUI.Managers;
using PhoenixDLL.GUI.Seekers;

namespace PhoenixDLL.GUI
{
    /// <summary>
    /// Main frame of the seeker
    /// </summary>
    public partial class fr_DeepPatientSeeker : Form
    {
        #region Variables
        /// <summary>
        /// Point for a visible Panel
        /// </summary>
        private Point vVisibleLocation;
        /// <summary>
        /// Point of a invisible Panel
        /// </summary>
        private Point vInvisibleLocation = new Point(9000, 9000);
        /// <summary>
        /// Patient manager to return
        /// </summary>
        private PatientManager vPatientManager = new PatientManager();
        #endregion

        #region Constructor
        /// <summary>
        /// Constructor
        /// </summary>
        public fr_DeepPatientSeeker()
        {
            InitializeComponent();            
            vVisibleLocation = tb_Text.Location;

            tb_Text.Location = this.vVisibleLocation;
            tb_Text.Dock = DockStyle.Fill;

            dtp_Date.Location = vInvisibleLocation;
            dtp_Date.Dock = DockStyle.None;
        }
        #endregion

        #region Methods
        /// <summary>
        /// Set the columns of the DataGridView
        /// </summary>
        private void SetColumnsOfDgv()
        {
            dgv_Result.Columns["id_Patient"].Visible = false;
            dgv_Result.Columns["Lieu_Naissance"].HeaderText = "Lieu de naissance";
            dgv_Result.Columns["Lieu_Naissance"].Visible = false;

            dgv_Result.Columns["DateNaissance"].HeaderText = "Date de naissance";

            dgv_Result.Columns["Code_Postal"].HeaderText = "Code postal";
            dgv_Result.Columns["Code_Postal"].Visible = false;

            dgv_Result.Columns["Telephone_Professionel"].HeaderText = "Tel. Pro.";
            dgv_Result.Columns["Telephone_Professionel"].Visible = false;

            dgv_Result.Columns["Telephone_Prive"].HeaderText = "Tel. priv";
            dgv_Result.Columns["Telephone_Prive"].Visible = false;

            dgv_Result.Columns["Derniere_MAJ"].HeaderText = "Dernire mj";
            dgv_Result.Columns["Derniere_MAJ"].Visible = false;

            dgv_Result.Columns["Motif_1"].HeaderText = "Motif 1";
            dgv_Result.Columns["Motif_1"].Visible = false;

            dgv_Result.Columns["Motif_2"].HeaderText = "Motif 2";
            dgv_Result.Columns["Motif_2"].Visible = false;

            dgv_Result.Columns["id_Reputation"].Visible = false;
            dgv_Result.Columns["id_Medecin"].Visible = false;
            dgv_Result.Columns["id_Homeopathe"].Visible = false;
            dgv_Result.Columns["FicheMedicale"].Visible = false;
            dgv_Result.Columns["Biodynamics"].Visible = false;
            dgv_Result.Columns["HE"].Visible = false;
            dgv_Result.Columns["FICHE_SUPPL_1"].Visible = false;
            dgv_Result.Columns["FICHE_SUPPL_2"].Visible = false;
            dgv_Result.Columns["FICHE_SUPPL_3"].Visible = false;
            dgv_Result.Columns["FICHE_SUPPL_4"].Visible = false;
            dgv_Result.Columns["rdvRemarques"].Visible = false;
            dgv_Result.Columns["id_honoraire"].Visible = false;
            dgv_Result.Columns["Kinergetique"].Visible = false;
            dgv_Result.Columns["Mauvais_Payeur"].Visible = false;
            dgv_Result.Columns["Dette_Patient"].Visible = false;
            dgv_Result.Columns["Honoraire"].Visible = false;

            dgv_Result.Columns["Adresse"].Visible = false;
            dgv_Result.Columns["Profession"].Visible = false;
            dgv_Result.Columns["Ville"].Visible = false;
            dgv_Result.Columns["Sexe"].Visible = false;
            dgv_Result.Columns["Mail"].Visible = false;
            dgv_Result.Columns["Prem_Consult"].Visible = false;
        }
        #endregion

        #region Events
        /// <summary>
        /// The RadioButton Checked property changed
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Event_rb_CheckedChanged(object sender, EventArgs e)
        {
            dtp_Date.Value = DateTime.Today;
            tb_Text.Text = "";

            //Search by profession
            if (rb_Profession.Checked)
            {
                #region Set the other panels invisible
                dtp_Date.Dock = DockStyle.None;
                dtp_Date.Location = this.vInvisibleLocation;
                #endregion

                gb_Seek.Text = "Profession:";
                tb_Text.Location = this.vVisibleLocation;
                tb_Text.Dock = DockStyle.Fill;
            }
            //Search by date of birth
            else if (rb_DateOfBirth.Checked)
            {
                #region Set the other panels invisible
                tb_Text.Dock = DockStyle.None;
                tb_Text.Location = vInvisibleLocation;
                #endregion

                gb_Seek.Text = "Date de naissance:";
                dtp_Date.Location = this.vVisibleLocation;
                dtp_Date.Dock = DockStyle.Fill;
            }
            else if (rb_ZipCode.Checked)
            {
                #region Set the other panels invisible
                dtp_Date.Dock = DockStyle.None;
                dtp_Date.Location = vInvisibleLocation;
                #endregion

                gb_Seek.Text = "Code postal:";
                tb_Text.Location = this.vVisibleLocation;
                tb_Text.Dock = DockStyle.Fill;
            }
            else if (rb_LastUpdate.Checked)
            {
                #region Set the other panels invisible
                tb_Text.Dock = DockStyle.None;
                tb_Text.Location = vInvisibleLocation;
                #endregion

                gb_Seek.Text = "Dernire mise  jour:";
                dtp_Date.Location = this.vVisibleLocation;
                dtp_Date.Dock = DockStyle.Fill;
            }
            else if (rb_BirthPlace.Checked)
            {
                #region Set the other panels invisible
                dtp_Date.Dock = DockStyle.None;
                dtp_Date.Location = vInvisibleLocation;
                #endregion

                gb_Seek.Text = "Lieu de naissance:";
                tb_Text.Location = this.vVisibleLocation;
                tb_Text.Dock = DockStyle.Fill;
            }
        }
        /// <summary>
        /// Seeking is asked
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Click_Seek(object sender, EventArgs e)
        {
            try
            {
                DataSet ds = new DataSet();
                if (rb_Profession.Checked)
                    ds = PatientSeeker.SeekByProfession(tb_Text.Text + "%");
                else if (rb_DateOfBirth.Checked)
                    ds = PatientSeeker.SeekByDateOfBirth(dtp_Date.Value);
                else if (rb_ZipCode.Checked)
                    ds = PatientSeeker.SeekByZipCode(tb_Text.Text + "%");
                else if (rb_LastUpdate.Checked)
                    ds = PatientSeeker.SeekByLastUpdate(dtp_Date.Value);
                else if (rb_BirthPlace.Checked)
                    ds = PatientSeeker.SeekByPlaceOfBirth(tb_Text.Text + "%");


                dgv_Result.DataSource = null;
                dgv_Result.DataSource = ds.Tables[0];
                SetColumnsOfDgv();
                if (ds.Tables[0].Rows.Count <= 0)

                    MessageBox.Show("Aucun rsultat!");
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "ERROR", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }

        }
        /// <summary>
        /// Double click on the DataGridView
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void DoubleClick_DataGridView(object sender, EventArgs e)
        {
            if (dgv_Result.Rows.Count <= 0) return;
            this.vPatientManager = PatientManager.Create((int)dgv_Result.SelectedRows[0].Cells["id_Patient"].Value);
            base.DialogResult = DialogResult.OK;
        }

        #region Menus
        /// <summary>
        /// Options menu
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void MenuClick_Options(object sender, EventArgs e)
        {
            fr_Options fr = new fr_Options();
            fr.ShowDialog();
        }
        /// <summary>
        /// Modify the selected patient
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Menu_ModifyPatient(object sender, EventArgs e)
        {
            if (dgv_Result.Rows.Count <= 0) return;
            PatientManager pm = PatientManager.Create((int)dgv_Result.SelectedRows[0].Cells["id_Patient"].Value);
            fr_PatientManager fr = new fr_PatientManager();
            fr.Text = "Modification de patient";
            fr.Manager = pm;
            fr.Use = Use.Update;
            fr.Size = new Size(fr.Size.Width, 600);
            fr.ShowDialog();
        }
        /// <summary>
        /// Down click on the DataGridView
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Event_DGV_MouseDown(object sender, MouseEventArgs e)
        {
            //if (e.Button == MouseButtons.Right)
            {
                DataGridView.HitTestInfo HitTestInfo = this.dgv_Result.HitTest(e.X, e.Y);
                if (HitTestInfo.RowIndex > -1)
                {
                    this.dgv_Result.SelectedRows[0].Selected = false;
                    this.dgv_Result.Rows[HitTestInfo.RowIndex].Selected = true;
                    pg_Patient.SelectedObject =
                        PatientManager.Create((int)dgv_Result.SelectedRows[0].Cells["id_Patient"].Value);                    
                }
            }
        }
        #endregion
        #endregion

        #region Properties
        /// <summary>
        /// Gets the selected patient
        /// </summary>
        public PatientManager SelectedItem { get { return vPatientManager; } }
        /// <summary>
        /// Retourne les informations sur les diffrentes fiches
        /// </summary>
        public CardsInfo CardsInfo
        {
            get
            {
                CardsInfo Card = new CardsInfo(); ;
                if (vPatientManager.IDPatient > 0)
                {
                    if (!DBNull.Value.Equals(dgv_Result.SelectedRows[0].Cells["Biodynamics"].Value))
                        Card.Biodynamics = (string)dgv_Result.SelectedRows[0].Cells["Biodynamics"].Value;
                    else
                        Card.Biodynamics = "";
                    if (!DBNull.Value.Equals(dgv_Result.SelectedRows[0].Cells["FicheMedicale"].Value))
                        Card.Cards = (string)dgv_Result.SelectedRows[0].Cells["FicheMedicale"].Value;
                    else
                        Card.Cards = "";

                    if (!DBNull.Value.Equals(dgv_Result.SelectedRows[0].Cells["HE"].Value))
                        Card.HE = (string)dgv_Result.SelectedRows[0].Cells["HE"].Value;
                    else
                        Card.HE = "";


                    Card.IsFilled = true;

                    if (!DBNull.Value.Equals(dgv_Result.SelectedRows[0].Cells["Kinergetique"].Value))
                        Card.Kinergetique = (string)dgv_Result.SelectedRows[0].Cells["Kinergetique"].Value;
                    else
                        Card.Kinergetique = "";
                    if (!DBNull.Value.Equals(dgv_Result.SelectedRows[0].Cells["FICHE_SUPPL_1"].Value))
                        Card.Tab1 = (string)dgv_Result.SelectedRows[0].Cells["FICHE_SUPPL_1"].Value;
                    else
                        Card.Tab1 = "";

                    if (!DBNull.Value.Equals(dgv_Result.SelectedRows[0].Cells["FICHE_SUPPL_2"].Value))
                        Card.Tab2 = (string)dgv_Result.SelectedRows[0].Cells["FICHE_SUPPL_2"].Value;
                    else
                        Card.Tab2 = "";
                    if (!DBNull.Value.Equals(dgv_Result.SelectedRows[0].Cells["FICHE_SUPPL_3"].Value))
                        Card.Tab3 = (string)dgv_Result.SelectedRows[0].Cells["FICHE_SUPPL_3"].Value;
                    else
                        Card.Tab3 = "";
                    if (!DBNull.Value.Equals(dgv_Result.SelectedRows[0].Cells["FICHE_SUPPL_4"].Value))
                        Card.Tab4 = (string)dgv_Result.SelectedRows[0].Cells["FICHE_SUPPL_4"].Value;
                    else
                        Card.Tab4 = "";
                    return Card;
                }
                else
                {
                    Card.IsFilled = false;
                    return Card;
                }
            }
        }
        #endregion
    }
}